import { jsx, jsxs } from "react/jsx-runtime";
import cn from "clsx";
import NextLink from "next/link";
const classes = {
  cards: cn(
    "nextra-cards _mt-4 _gap-4 _grid",
    "_not-prose"
    // for nextra-theme-blog
  ),
  card: cn(
    "nextra-card _group _flex _flex-col _justify-start _overflow-hidden _rounded-lg _border _border-gray-200",
    "_text-current _no-underline dark:_shadow-none",
    "hover:_shadow-gray-100 dark:hover:_shadow-none _shadow-gray-100",
    "active:_shadow-sm active:_shadow-gray-200",
    "_transition-all _duration-200 hover:_border-gray-300"
  ),
  title: cn(
    "_flex _font-semibold _items-start _gap-2 _p-4 _text-gray-700 hover:_text-gray-900"
  )
};
const arrowEl = /* @__PURE__ */ jsx("span", { className: "_transition-transform _duration-75 group-hover:_translate-x-[2px]", children: "\u2192" });
function Card({
  children,
  title,
  icon,
  image,
  arrow,
  href,
  ...props
}) {
  const animatedArrow = arrow ? arrowEl : null;
  if (image) {
    return /* @__PURE__ */ jsxs(
      NextLink,
      {
        href,
        className: cn(
          classes.card,
          "_bg-gray-100 _shadow dark:_border-neutral-700 dark:_bg-neutral-800 dark:_text-gray-50 hover:_shadow-lg dark:hover:_border-neutral-500 dark:hover:_bg-neutral-700"
        ),
        ...props,
        children: [
          children,
          /* @__PURE__ */ jsxs(
            "span",
            {
              className: cn(
                classes.title,
                "dark:_text-gray-300 dark:hover:_text-gray-100"
              ),
              children: [
                icon,
                /* @__PURE__ */ jsxs("span", { className: "_flex _gap-1", children: [
                  title,
                  animatedArrow
                ] })
              ]
            }
          )
        ]
      }
    );
  }
  return /* @__PURE__ */ jsx(
    NextLink,
    {
      href,
      className: cn(
        classes.card,
        "_bg-transparent _shadow-sm dark:_border-neutral-800 hover:_bg-slate-50 hover:_shadow-md dark:hover:_border-neutral-700 dark:hover:_bg-neutral-900"
      ),
      ...props,
      children: /* @__PURE__ */ jsxs(
        "span",
        {
          className: cn(
            classes.title,
            "dark:_text-neutral-200 dark:hover:_text-neutral-50 _flex _items-center"
          ),
          children: [
            icon,
            title,
            animatedArrow
          ]
        }
      )
    }
  );
}
function _Cards({
  children,
  num = 3,
  className,
  style,
  ...props
}) {
  return /* @__PURE__ */ jsx(
    "div",
    {
      className: cn(classes.cards, className),
      ...props,
      style: {
        ...style,
        "--rows": num
      },
      children
    }
  );
}
const Cards = Object.assign(_Cards, { displayName: "Cards", Card });
export {
  Cards
};
