import { jsx, jsxs } from "react/jsx-runtime";
import { Tab as HeadlessTab } from "@headlessui/react";
import cn from "clsx";
import { useCallback, useEffect, useState } from "react";
function isTabObjectItem(item) {
  return !!item && typeof item === "object" && "label" in item;
}
function _Tabs({
  items,
  selectedIndex: _selectedIndex,
  defaultIndex = 0,
  onChange,
  children,
  storageKey
}) {
  const [selectedIndex, setSelectedIndex] = useState(defaultIndex);
  useEffect(() => {
    if (_selectedIndex !== void 0) {
      setSelectedIndex(_selectedIndex);
    }
  }, [_selectedIndex]);
  useEffect(() => {
    if (!storageKey) {
      return;
    }
    function fn(event) {
      if (event.key === storageKey) {
        setSelectedIndex(Number(event.newValue));
      }
    }
    const index = Number(localStorage.getItem(storageKey));
    setSelectedIndex(Number.isNaN(index) ? 0 : index);
    window.addEventListener("storage", fn);
    return () => {
      window.removeEventListener("storage", fn);
    };
  }, []);
  const handleChange = useCallback((index) => {
    if (storageKey) {
      const newValue = String(index);
      localStorage.setItem(storageKey, newValue);
      window.dispatchEvent(
        new StorageEvent("storage", { key: storageKey, newValue })
      );
      return;
    }
    setSelectedIndex(index);
    onChange?.(index);
  }, []);
  return /* @__PURE__ */ jsxs(
    HeadlessTab.Group,
    {
      selectedIndex,
      defaultIndex,
      onChange: handleChange,
      children: [
        /* @__PURE__ */ jsx("div", { className: "nextra-scrollbar _overflow-x-auto _overflow-y-hidden _overscroll-x-contain", children: /* @__PURE__ */ jsx(HeadlessTab.List, { className: "_mt-4 _flex _w-max _min-w-full _border-b _border-gray-200 _pb-px dark:_border-neutral-800", children: items.map((item, index) => {
          const disabled = isTabObjectItem(item) && item.disabled;
          return /* @__PURE__ */ jsx(
            HeadlessTab,
            {
              disabled,
              className: ({ selected }) => cn(
                "_mr-2 _rounded-t _p-2 _font-medium _leading-5 _transition-colors",
                "_-mb-0.5 _select-none _border-b-2",
                selected ? "_border-primary-500 _text-primary-600" : "_border-transparent _text-gray-600 hover:_border-gray-200 hover:_text-black dark:_text-gray-200 dark:hover:_border-neutral-800 dark:hover:_text-white",
                disabled && "_pointer-events-none _text-gray-400 dark:_text-neutral-600"
              ),
              children: isTabObjectItem(item) ? item.label : item
            },
            index
          );
        }) }) }),
        /* @__PURE__ */ jsx(HeadlessTab.Panels, { children })
      ]
    }
  );
}
function Tab({
  children,
  ...props
}) {
  return /* @__PURE__ */ jsx(HeadlessTab.Panel, { ...props, className: "_rounded _pt-6", children });
}
const Tabs = Object.assign(_Tabs, { displayName: "Tabs", Tab });
export {
  Tabs
};
