import { bundledLanguages, getHighlighter } from "shiki";
import { visit } from "unist-util-visit";
const CODE_BLOCK_FILENAME_REGEX = /filename="([^"]+)"/;
const DEFAULT_REHYPE_PRETTY_CODE_OPTIONS = {
  keepBackground: false,
  grid: false,
  onVisitLine(node) {
    if (node.children.length === 0) {
      node.children.push({ type: "text", value: " " });
    }
    delete node.properties["data-line"];
  },
  filterMetaString: (meta) => meta.replace(CODE_BLOCK_FILENAME_REGEX, ""),
  async getHighlighter(_opts) {
    const DEFAULT_OPTS = {
      themes: {
        light: "github-light",
        dark: "github-dark"
      },
      defaultColor: false
    };
    const highlighter = await getHighlighter({
      themes: Object.values(DEFAULT_OPTS.themes),
      langs: Object.keys(bundledLanguages)
    });
    const originalCodeToHtml = highlighter.codeToHtml;
    return Object.assign(highlighter, {
      codeToHtml(code, lang) {
        return originalCodeToHtml(code, { lang, ...DEFAULT_OPTS });
      },
      ansiToHtml(code) {
        return this.codeToHtml(code, "ansi");
      }
    });
  }
};
const rehypeParseCodeMeta = ({ defaultShowCopyCode }) => (ast) => {
  visit(ast, { tagName: "pre" }, (node) => {
    const [codeEl] = node.children;
    const meta = codeEl.data?.meta;
    node.__filename = meta?.match(CODE_BLOCK_FILENAME_REGEX)?.[1];
    node.properties["data-filename"] = node.__filename;
    node.__hasCopyCode = meta ? defaultShowCopyCode && !/( |^)copy=false($| )/.test(meta) || /( |^)copy($| )/.test(meta) : defaultShowCopyCode;
    if (node.__hasCopyCode) {
      node.properties["data-copy"] = "";
    }
  });
};
const rehypeAttachCodeMeta = () => (ast) => {
  visit(ast, [{ tagName: "div" }, { tagName: "span" }], (node) => {
    const isRehypePrettyCode = "data-rehype-pretty-code-fragment" in node.properties;
    if (!isRehypePrettyCode)
      return;
    const preEl = Object.assign(node, node.children[0]);
    delete preEl.properties["data-theme"];
    if (preEl.tagName === "pre") {
      const [codeEl] = preEl.children;
      delete codeEl.properties["data-theme"];
      delete codeEl.properties["data-language"];
      if (preEl.__filename) {
        preEl.properties["data-filename"] = preEl.__filename;
      }
      if (preEl.__hasCopyCode) {
        preEl.properties["data-copy"] = "";
      }
      if (preEl.type === "mdxJsxFlowElement") {
        preEl.attributes.push(
          ...Object.entries(node.properties).map(([name, value]) => ({
            type: "mdxJsxAttribute",
            name,
            value
          }))
        );
      }
    } else {
      delete node.children[0].properties.className;
    }
  });
};
export {
  DEFAULT_REHYPE_PRETTY_CODE_OPTIONS,
  rehypeAttachCodeMeta,
  rehypeParseCodeMeta
};
