import Slugger from "github-slugger";
import { visit } from "unist-util-visit";
import { MARKDOWN_EXTENSION_REGEX } from "../constants.js";
const getFlattenedValue = (node) => node.children.map(
  (child) => "children" in child ? getFlattenedValue(child) : "value" in child ? child.value : ""
).join("");
const SKIP_FOR_PARENT_NAMES = /* @__PURE__ */ new Set(["Tab", "Tabs.Tab"]);
const remarkHeadings = ({ exportName = "useTOC", isRemoteContent }) => {
  const headings = [];
  let hasJsxInH1;
  const slugger = new Slugger();
  return (ast, file) => {
    const PartialComponentToHeadingsName = /* @__PURE__ */ Object.create(null);
    visit(
      ast,
      [
        "heading",
        // push partial component's `useTOC` export name to headings list
        "mdxJsxFlowElement",
        // verify .md/.mdx exports and attach named `useTOC` export
        "mdxjsEsm"
      ],
      (node, _index, parent) => {
        var _a;
        if (node.type === "heading") {
          if (node.depth === 1) {
            const hasJsx = node.children.some(
              (child) => child.type === "mdxJsxTextElement"
            );
            if (hasJsx) {
              hasJsxInH1 = true;
            }
            return;
          }
          node.data || (node.data = {});
          const headingProps = (_a = node.data).hProperties || (_a.hProperties = {});
          if (SKIP_FOR_PARENT_NAMES.has(parent.name)) {
            delete headingProps.id;
          } else {
            const value = getFlattenedValue(node);
            const id = slugger.slug(headingProps.id || value);
            headingProps.id = id;
            headings.push({ depth: node.depth, value, id });
          }
          return;
        }
        if (isRemoteContent) {
        } else if (node.type === "mdxjsEsm") {
          for (const child of node.data.estree.body) {
            if (child.type !== "ImportDeclaration")
              continue;
            const importPath = child.source.value;
            const isMdxImport = MARKDOWN_EXTENSION_REGEX.test(importPath);
            if (!isMdxImport)
              continue;
            const componentName = child.specifiers.find(
              (o) => o.type === "ImportDefaultSpecifier"
            )?.local.name;
            if (!componentName)
              continue;
            const { length } = Object.keys(PartialComponentToHeadingsName);
            const exportAsName = `${exportName}${length}`;
            PartialComponentToHeadingsName[componentName] = exportAsName;
            child.specifiers.push({
              type: "ImportSpecifier",
              imported: { type: "Identifier", name: exportName },
              local: { type: "Identifier", name: exportAsName }
            });
          }
        } else {
          const headingsName = PartialComponentToHeadingsName[node.name];
          if (headingsName) {
            headings.push(headingsName);
          }
        }
      }
    );
    file.data.hasJsxInH1 = hasJsxInH1;
    file.data.toc = headings;
  };
};
export {
  getFlattenedValue,
  remarkHeadings
};
