import path from "path";
import slash from "slash";
import title from "title";
import { DEFAULT_PROPERTY_PROPS } from "./constants.js";
function truthy(value) {
  return !!value;
}
const logger = {
  info: console.log.bind(null, "-", "\x1B[36minfo\x1B[0m", "[nextra]"),
  warn: console.log.bind(null, "-", "\x1B[33mwarn\x1B[0m", "[nextra]"),
  error: console.log.bind(null, "-", "\x1B[31merror\x1B[0m", "[nextra]")
};
function pageTitleFromFilename(fileName) {
  return title(fileName.replaceAll(/[-_]/g, " "), { special: ["SSR"] });
}
function sortPages(pages, locale) {
  return pages.map((item) => ({
    name: item.name,
    date: "frontMatter" in item && item.frontMatter?.date,
    title: "frontMatter" in item && item.frontMatter?.title || pageTitleFromFilename(item.name)
  })).sort((a, b) => {
    if (a.date && b.date) {
      return new Date(b.date).getTime() - new Date(a.date).getTime();
    }
    if (a.date) {
      return -1;
    }
    if (b.date) {
      return 1;
    }
    return a.title.localeCompare(b.title, locale || void 0, {
      numeric: true
    });
  }).map((item) => [item.name, item.title]);
}
function normalizePageRoute(parentRoute, route) {
  return slash(path.join(parentRoute, route.replace(/^index$/, "")));
}
function createAstExportConst(name, value) {
  return {
    type: "ExportNamedDeclaration",
    specifiers: [],
    declaration: {
      type: "VariableDeclaration",
      kind: "const",
      declarations: [
        {
          type: "VariableDeclarator",
          id: { type: "Identifier", name },
          init: value
        }
      ]
    }
  };
}
function createAstObject(obj) {
  return {
    type: "ObjectExpression",
    properties: Object.entries(obj).map(([key, value]) => ({
      ...DEFAULT_PROPERTY_PROPS,
      key: { type: "Identifier", name: key },
      value: value && typeof value === "object" ? value : { type: "Literal", value }
    }))
  };
}
export {
  createAstExportConst,
  createAstObject,
  logger,
  normalizePageRoute,
  pageTitleFromFilename,
  sortPages,
  truthy
};
