import path from "node:path";
import gracefulFs from "graceful-fs";
import { CHUNKS_DIR, IS_PRODUCTION } from "../constants.js";
import { PAGES_DIR } from "../file-system.js";
import { collectPageMap } from "../page-map.js";
const fs = gracefulFs.promises;
let isSaved = false;
class NextraPlugin {
  constructor(config) {
    this.config = config;
  }
  apply(compiler) {
    const pluginName = this.constructor.name;
    const { locales, transformPageMap } = this.config;
    compiler.hooks.beforeCompile.tapAsync(pluginName, async (_, callback) => {
      if (IS_PRODUCTION && isSaved) {
        callback();
        return;
      }
      if (!isSaved) {
        await fs.mkdir(path.join(CHUNKS_DIR), { recursive: true });
      }
      try {
        for (const locale of locales) {
          const route = `/${locale}`;
          const dir = path.join(PAGES_DIR, locale);
          const rawJs = await collectPageMap({
            dir,
            route,
            locale,
            transformPageMap
          });
          await fs.writeFile(
            path.join(CHUNKS_DIR, `nextra-page-map-${locale}.mjs`),
            rawJs
          );
        }
        isSaved = true;
        callback();
      } catch (error) {
        callback(error);
      }
    });
  }
}
export {
  NextraPlugin
};
